@@ -4,7 +4,10 @@ Created on Sun Sep 20 19:42:22 2020
 
 @author: TheFermiSea
 """
-import stellarnet as sn
+try:
+    import stellarnet as sn
+except:
+    print("Stellarnet doesn't let people distribute stellarnet.py. The repository which has it https://github.com/acpo/PiSpec20_LED_stellarnet took it down at their request and there is absolutely no way to look at old git commits")
 import matplotlib as mpl
 mpl.use('Qt5Agg')
 import matplotlib.pyplot as plt
