@@ -1,10 +1,12 @@
 import pyvisa
-from time import sleep
+name = "esp300"
+hwid = [""]
 
 class ESP300:
-    def __init__(self):
+    def __init__(self, port):
         self.rm = pyvisa.ResourceManager()
-        self.esp = self.rm.open_resource('ASRL/dev/ttyUSB1::INSTR')
+        current_port = port.name
+        self.esp = self.rm.open_resource(f'ASRL/{current_port}::INSTR')
         self.esp.baud_rate = 19200
 
     def moveAbs(self,axis, position):
@@ -36,5 +38,3 @@ class ESP300:
 
 if __name__=='__main__':
     ESP300 = ESP300()
-
-    
