@@ -14,8 +14,8 @@ def find_ports(type):
 
 
 class instrument:
-    def __init__(self, i):
-        self.rotator = K10CR1(i)
+    def __init__(self, port):
+        self.rotator = K10CR1(port.serial_number)
         self.home()
 
     def home(self):
